import pathlib

import pytube


class Content:
    def __init__(self, url: str, destination: pathlib.Path) -> None:
        self._url = url
        self._destination = destination
        self._content = pytube.YouTube(url)

    @property
    def url(self) -> str:
        return self._url

    @property
    def destination(self) -> pathlib.Path:
        return self._destination

    @property
    def content(self):
        return self._content

    def download(self) -> None:
        self.content.streams.get_highest_resolution().download(self.destination)



from mediagrab.content import Content
from mediagrab.parser import parser


def main():
    args: dict = vars(parser.parse_args())
    video = Content(**args)
    video.download()


if __name__ == "__main__":
    main()



import argparse
import pathlib

parser = argparse.ArgumentParser()

parser.add_argument(
    "url",
    type=str,
    help="URL of video on YouTube to download",
)

parser.add_argument(
    "-d",
    "--destination",
    type=pathlib.Path,
    help="destination path",
    required=False,
)
